@@ -2,7 +2,7 @@ package Starman;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.2008_2';
+our $VERSION = '0.1000';
 
 1;
 __END__
@@ -13,7 +13,7 @@ __END__
 
 =head1 NAME
 
-Starman - High-performance preforking PSGI/Plack web server
+Starman - High-performance preforking PSGI web server
 
 =head1 SYNOPSIS
 
@@ -21,7 +21,7 @@ Starman - High-performance preforking PSGI/Plack web server
   > starman
 
   # run with Server::Starter
-  > start_server --port 127.0.0.1:80 -- starman --workers 32 myapp.psgi
+  > start_server --port 127.0.0.1:80 -- starman --max-servers 32 myapp.psgi
 
   # UNIX domain sockets
   > starman --listen /tmp/starman.sock
@@ -57,10 +57,9 @@ Able to listen on multiple intefaces including UNIX sockets.
 
 =item Small memory footprint
 
-Preloading the applications with C<--preload-app> command line option
-enables copy-on-write friendly memory management. Also, the minimum
-memory usage Starman requires for the master process is 7MB and
-children (workers) is less than 3.0MB.
+Preloading the applications enables copy-on-write friendly memory
+management. Also, the minimum memory usage Starman requires for the
+master process is 7MB and children (workers) is less than 3.0MB.
 
 =item PSGI compatible
 
@@ -70,29 +69,25 @@ Can run any PSGI applications and frameworks
 
 Supports chunked requests and responses, keep-alive and pipeline requests.
 
-=item UNIX only
-
-This server does not support Win32.
-
 =back
 
 =head1 PERFORMANCE
 
 Here's a simple benchmark using C<Hello.psgi>.
 
-  -- server: Starman (workers=10)
-  Requests per second:    6849.16 [#/sec] (mean)
-  -- server: Twiggy
+  -- server: Starman
+  Requests per second:    6413.87 [#/sec] (mean)
+  -- server: AnyEvent
   Requests per second:    3911.78 [#/sec] (mean)
   -- server: AnyEvent::HTTPD
   Requests per second:    2738.49 [#/sec] (mean)
-  -- server: HTTP::Server::PSGI
-  Requests per second:    2218.16 [#/sec] (mean)
-  -- server: HTTP::Server::PSGI (workers=10)
+  -- server: Standalone
+  Requests per second:    1045.66 [#/sec] (mean)
+  -- server: Standalone (prefork)
   Requests per second:    2792.99 [#/sec] (mean)
   -- server: HTTP::Server::Simple
   Requests per second:    1435.50 [#/sec] (mean)
-  -- server: Corona
+  -- server: Coro
   Requests per second:    2332.00 [#/sec] (mean)
   -- server: POE
   Requests per second:    503.59 [#/sec] (mean)
@@ -105,15 +100,14 @@ This benchmark was processed with C<ab -c 10 -t 1 -k> on MacBook Pro
 =head2 Starman?
 
 The name Starman is taken from the song (I<Star na Otoko>) by the
-Japanese rock band Unicorn (yes, Unicorn!). It's also known as a song
-by David Bowie, a power-up from Super Mario Brothers and a character
-from Earthbound, all of which I love.
+Japanese rock band Unicorn. It's also a power-up from Super Mario
+Brothers and a character from the video game Earthbound.
 
 =head2 Why the cute name instead of more descriptive namespace? Are you on drugs?
 
 I'm sick of naming Perl software like
 HTTP::Server::PSGI::How::Its::Written::With::What::Module and people
-call it HSPHIWWWM on IRC. It's hard to say on speeches and newbies
+call it HSSPHIWWWM on IRC. It's hard to say on speeches and newbies
 would ask questions what they stand for every day. That's crazy.
 
 This module actually includes the longer alias and an empty subclass
