@@ -34,9 +34,6 @@ sub run {
     if ( $options->{daemonize} ) {
         $extra{setsid} = $extra{background} = 1;
     }
-    if (! exists $options->{keepalive}) {
-        $options->{keepalive} = 1;
-    }
 
     my($host, $port, $proto);
     for my $listen (@{$options->{listen} || [ "$options->{host}:$options->{port}" ]}) {
@@ -66,11 +63,11 @@ sub run {
         max_spare_servers          => $options->{max_spare_servers} || $workers - 1,
         max_servers                => $options->{max_servers}       || $workers,
         max_requests               => $options->{max_requests}      || 1000,
+        leave_children_open_on_hup => 1,
         user                       => $options->{user}              || $>,
         group                      => $options->{group}             || $),
         listen                     => $options->{backlog}           || 1024,
-        leave_children_open_on_hup => 1, # XXX conigurable?
-        no_client_stdout           => 1,
+
         %extra
     );
 }
@@ -92,23 +89,14 @@ sub pre_loop_hook {
         TTIN => sub { $self->{server}->{$_}++ for qw( min_servers max_servers ) },
         TTOU => sub { $self->{server}->{$_}-- for qw( min_servers max_servers ) },
     );
-}
 
-sub run_parent {
-    my $self = shift;
     $0 = "starman master " . join(" ", @{$self->{options}{argv} || []});
-    $self->SUPER::run_parent(@_);
 }
 
 # The below methods run in the child process
 
 sub child_init_hook {
     my $self = shift;
-    srand();
-    if ($self->{options}->{psgi_app_builder}) {
-        DEBUG && warn "[$$] Initializing the PSGI app\n";
-        $self->{app} = $self->{options}->{psgi_app_builder}->();
-    }
     $0 = "starman worker " . join(" ", @{$self->{options}{argv} || []});
 }
 
@@ -141,7 +129,7 @@ sub process_request {
             REMOTE_ADDR     => $self->{server}->{peeraddr},
             REMOTE_HOST     => $self->{server}->{peerhost} || $self->{server}->{peeraddr},
             SERVER_NAME     => $self->{server}->{sockaddr}, # XXX: needs to be resolved?
-            SERVER_PORT     => $self->{server}->{sockport},
+            SERVER_PORT     => $self->{server}->{port}->[0],
             SCRIPT_NAME     => '',
             'psgi.version'      => [ 1, 1 ],
             'psgi.errors'       => *STDERR,
@@ -189,7 +177,7 @@ sub process_request {
             # Do we need to send 100 Continue?
             if ( $env->{HTTP_EXPECT} ) {
                 if ( $env->{HTTP_EXPECT} eq '100-continue' ) {
-                    syswrite $conn, 'HTTP/1.1 100 Continue' . $CRLF . $CRLF;
+                    syswrite STDOUT, 'HTTP/1.1 100 Continue' . $CRLF . $CRLF;
                     DEBUG && warn "[$$] Sent 100 Continue response\n";
                 }
                 else {
@@ -207,11 +195,6 @@ sub process_request {
             }
         }
 
-        unless ($self->{options}->{keepalive}) {
-            DEBUG && warn "[$$] keep-alive is disabled. Closing the connection after this request\n";
-            $self->{client}->{keepalive} = 0;
-        }
-
         $self->_prepare_env($env);
 
         # Run PSGI apps
@@ -270,10 +253,10 @@ sub _read_headers {
             # Do we have a full header in the buffer?
             # This is before sysread so we don't read if we have a pipelined request
             # waiting in the buffer
-            last if defined $self->{client}->{inputbuf} && $self->{client}->{inputbuf} =~ /$CRLF$CRLF/s;
+            last if $self->{client}->{inputbuf} =~ /$CRLF$CRLF/s;
 
             # If not, read some data
-            my $read = sysread $self->{server}->{client}, my $buf, CHUNKSIZE;
+            my $read = sysread STDIN, my $buf, CHUNKSIZE;
 
             if ( !defined $read || $read == 0 ) {
                 die "Read error: $!\n";
@@ -334,7 +317,7 @@ sub _prepare_env {
             my $chunk = delete $self->{client}->{inputbuf};
             return ($chunk, length $chunk);
         }
-        my $read = sysread $self->{server}->{client}, my($chunk), CHUNKSIZE;
+        my $read = sysread STDIN, my($chunk), CHUNKSIZE;
         return ($chunk, $read);
     };
 
@@ -344,11 +327,6 @@ sub _prepare_env {
         my $buf = Plack::TempBuffer->new($cl);
         while ($cl > 0) {
             my($chunk, $read) = $get_chunk->();
-
-            if ( !defined $read || $read == 0 ) {
-                die "Read error: $!\n";
-            }
-
             $cl -= $read;
             $buf->print($chunk);
         }
@@ -409,7 +387,7 @@ sub _finalize_response {
     }
 
     if ( $protocol eq 'HTTP/1.1' ) {
-        if ( !exists $headers{'content-length'} ) {
+        if ( !$headers{'content-length'} ) {
             if ( $status !~ /^1\d\d|[23]04$/ ) {
                 DEBUG && warn "[$$] Using chunked transfer-encoding to send unknown length body\n";
                 push @headers, 'Transfer-Encoding: chunked';
@@ -422,14 +400,9 @@ sub _finalize_response {
                 $chunked = 1;
             }
         }
-    } else {
-        if ( !exists $headers{'content-length'} ) {
-            DEBUG && warn "[$$] Disabling keep-alive after sending unknown length body on $protocol\n";
-            $self->{client}->{keepalive} = 0;
-        }
     }
 
-    if ( ! $headers{date} ) {
+    if ( ! $headers{Date} ) {
         push @headers, "Date: " . time2str( time() );
     }
 
@@ -440,11 +413,9 @@ sub _finalize_response {
         push @headers, 'Connection: close';
     }
 
-    my $conn = $self->{server}->{client};
-
     # Buffer the headers so they are sent with the first write() call
     # This reduces the number of TCP packets we are sending
-    syswrite $conn, join( $CRLF, @headers, '' ) . $CRLF;
+    syswrite STDOUT, join( $CRLF, @headers, '' ) . $CRLF;
 
     if (defined $res->[2]) {
         Plack::Util::foreach($res->[2], sub {
@@ -453,11 +424,11 @@ sub _finalize_response {
                 my $len = length $buffer;
                 $buffer = sprintf( "%x", $len ) . $CRLF . $buffer . $CRLF;
             }
-            syswrite $conn, $buffer;
+            syswrite STDOUT, $buffer;
             DEBUG && warn "[$$] Wrote " . length($buffer) . " bytes\n";
         });
 
-        syswrite $conn, "0$CRLF$CRLF" if $chunked;
+        syswrite STDOUT, "0$CRLF$CRLF" if $chunked;
     } else {
         return Plack::Util::inline_object
             write => sub {
@@ -466,11 +437,11 @@ sub _finalize_response {
                     my $len = length $buffer;
                     $buffer = sprintf( "%x", $len ) . $CRLF . $buffer . $CRLF;
                 }
-                syswrite $conn, $buffer;
+                syswrite STDOUT, $buffer;
                 DEBUG && warn "[$$] Wrote " . length($buffer) . " bytes\n";
             },
             close => sub {
-                syswrite $conn, "0$CRLF$CRLF" if $chunked;
+                syswrite STDOUT, "0$CRLF$CRLF" if $chunked;
             };
     }
 }
